==> vtigercrm-5.3.0p0.tgz: modules/Documents/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Notes/language/en_us.lang.php,v 1.10 2005/03/28 06:33:37 rank Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Documentos',
'LBL_MODULE_TITLE'=>'Documentos: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar Documento',
'LBL_LIST_FORM_TITLE'=>'Listar Documento',
'LBL_NEW_FORM_TITLE'=>'Novo Documento',

'LBL_LIST_SUBJECT'=>'Assunto',
'LBL_LIST_CONTACT_NAME'=>'Nome Contato',
'LBL_LIST_RELATED_TO'=>'Relacionado à',
'LBL_LIST_DATE_MODIFIED'=>'Última Modificação',

'LBL_NOTE'=>'Documento:',
'LBL_NOTE_SUBJECT'=>'Assunto Documento:',
'LBL_CONTACT_NAME'=>'Nome Contato:',
'LBL_PHONE'=>'Telefone:',
'LBL_SUBJECT'=>'Assunto:',
'LBL_CLOSE'=>'Fechar:',
'LBL_RELATED_TO'=>'Relacionado à:',
'LBL_EMAIL_ADDRESS'=>'E-mail:',
'LBL_COLON'=>':',

'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a vtiger_account.",
'LBL_LIST_FILENAME'=>"Arquivo",

// Added for Note(3.2-patch 3)

'LBL_FILENAME'=>'Anexo:',
'LBL_NOTE_INFORMATION'=>'Informação do Documento',
'File Information'=>'Informação do Arquivo',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Documento',
// Added for 4GA
'Contact Name'=>'Nome Contato',
'Related To'=>'Relacionado à',
'Subject'=>'Assunto',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Document'=>'Documento',
'Note'=>'Notas',
//Added for 4.2 Release -- CustomView
'Related to'=>'Relacionado à',
'Last Modified'=>'Última Modificação',
'File'=>'Arquivo',
'LBL_ALL'=>'Todas',
'Title'=>'Título',

//Added after 504 for Downloads Module
'LBL_FILE_INFORMATION'=>'Informação Arquivo',
'LBL_FILE_NAME'=>'Nome Arquivo',
'LBL_FILE_TYPE'=>'Tipo Arquivo',
'LBL_FILE_SIZE'=>'Tamanho',
'filelocationtype'=>'Tipo Download',
'fileversion'=>'Versão',
'filestatus'=>'Ativo',
'filedownloadcount'=>'Contar Download',
'os'=>'Plataforma',
'LBL_FOLDER_NAME'=>'Nome Pasta',
'LBL_DOWNLOAD_TYPE'=>'Tipo Download',
'LBL_INTERNAL'=>'Interno',
'LBL_EXTERNAL'=>'Externo',
'LBL_EXTERNAL_FILE_NAME'=>'Nome Arquivo',
'LBL_FILE_LOCATION'=>'Localização Arquivo',
'LBL_PD'=>'Plataforma Dependente',
'LBL_PIND'=>'Plataforma Independente',
'ChoosePlatform'=>'Escolha Plataforma',
'LBL_ACTIVE'=>'Ativo',
'LBL_INACTIVE'=>'Inativo',
'LBL_UPLOAD_BUTTON'=>'Transferir',
'architecture'=>'Arquitetura',
'LBL_DOWNLOAD_FILE'=>'Download Arquivo',
'LBL_CHECK_INTEGRITY'=>'Checar integridade arquivo',
'LBL_EMAIL_FILE'=>'Enviar Email com arquivo anexado',
'LBL_CLICK_HERE'=>'Clique aqui',
'LBL_TO_ADD_FOLDER'=>'para adicionar uma nova pasta.',
'LBL_DELETE_FOLDER'=>'Apagar Pasta',
'LBL_FOLDER_DESC'=>'Descrição',
'LBL_ADD_NEW_FOLDER'=>'Adicionar Pasta',
'LBL_DELETE_DOCUMENTS'=>'Apagar Documento(s)',
'LBL_MOVE_TO'=>'Mover para',
'File Name'=>'Nome Arquivo',
'File Type'=>'Tipo Arquivo',
'File Size'=>'Tamanho',
'LBL_INTERNAL'=>'Interno',
'LBL_URL'=>'URL',
'LBL_EXTERNAL'=>'Externo',
'LBL_EXTERNAL_LNK'=>'Link Externo',
'LBL_ACTIVE'=>'Ativo',
'LBL_INACTIVE'=>'Inativo',
'LBL_PLATFORM_INDEPENDENT'=>'Plataforma Independente',
'LNK_DOWNLOAD'=>'download',
'LBL_MOVE_DOCUMENTS'=>'Mover Documento(s)',
'LBL_MOVE'=>'Mover',
'Download Type'=>'Tipo Download',
'Version'=>'Versão',
'Active'=>'Ativo',
'Download Count'=>'Contar Download',
'Platform'=>'Plataforma',
'Assigned To'=>'Atribuído à',
// Module Sequence Numbering
'Note No' => 'No. Documento',
// END

// Documents module
'LBL_EMPTY_FOLDERS' => 'Pastas Vazias',
'LBL_VIEW_EMPTY_FOLDERS' => 'Visualizar Pastas Vazias',
'LBL_NO_DOCUMENTS' => 'Nenhum Documento',
'LBL_DESCRIPTION' => 'Descrição',
'FILE_HAS_NO_DATA'=>'O arquivo selecionado não possui dados ou o é inválido',

'LBL_MAXIMUM_20'=>'Máximo 20',
'LBL_MAXIMUM_50'=>'Máximo 50',

// Added after 5.1.0 GA
'Folder Name'=>'Nome Pasta',
'Document No'=>'No. Documento',
);

?>

==> vtigercrm-5.4.0.tgz: modules/Documents/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Notes/language/en_us.lang.php,v 1.10 2005/03/28 06:33:37 rank Exp $
 * Description:  Defines the English language pack for the Documents module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Documentos',
'LBL_MODULE_TITLE'=>'Documentos: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar Documento',
'LBL_LIST_FORM_TITLE'=>'Listar Documento',
'LBL_NEW_FORM_TITLE'=>'Novo Documento',

'LBL_LIST_SUBJECT'=>'Assunto',
'LBL_LIST_CONTACT_NAME'=>'Nome Contato',
'LBL_LIST_RELATED_TO'=>'Relacionado à',
'LBL_LIST_DATE_MODIFIED'=>'Última Modificação',

'LBL_NOTE'=>'Documento:',
'LBL_NOTE_SUBJECT'=>'Assunto Documento:',
'LBL_CONTACT_NAME'=>'Nome Contato:',
'LBL_PHONE'=>'Telefone:',
'LBL_SUBJECT'=>'Assunto:',
'LBL_CLOSE'=>'Fechar:',
'LBL_RELATED_TO'=>'Relacionado à:',
'LBL_EMAIL_ADDRESS'=>'E-mail:',
'LBL_COLON'=>':',

'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a vtiger_account.",
'LBL_LIST_FILENAME'=>"Arquivo",

// Added for Note(3.2-patch 3)

'LBL_FILENAME'=>'Anexo:',
'LBL_NOTE_INFORMATION'=>'Informação do Documento',
'File Information'=>'Informação do Arquivo',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Documento',
// Added for 4GA
'Contact Name'=>'Nome Contato',
'Related To'=>'Relacionado à',
'Subject'=>'Assunto',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Document'=>'Documento',
'Note'=>'Notas',
//Added for 4.2 Release -- CustomView
'Related to'=>'Relacionado à',
'Last Modified'=>'Última Modificação',
'File'=>'Arquivo',
'LBL_ALL'=>'Todas',
'Title'=>'Título',

//Added after 504 for Downloads Module
'LBL_FILE_INFORMATION'=>'Informação Arquivo',
'LBL_FILE_NAME'=>'Nome Arquivo',
'LBL_FILE_TYPE'=>'Tipo Arquivo',
'LBL_FILE_SIZE'=>'Tamanho',
'filelocationtype'=>'Tipo Download',
'fileversion'=>'Versão',
'filestatus'=>'Ativo',
'filedownloadcount'=>'Contar Download',
'os'=>'Plataforma',
'LBL_FOLDER_NAME'=>'Nome Pasta',
'LBL_DOWNLOAD_TYPE'=>'Tipo Download',
'LBL_INTERNAL'=>'Interno',
'LBL_EXTERNAL'=>'Externo',
'LBL_EXTERNAL_FILE_NAME'=>'Nome Arquivo',
'LBL_FILE_LOCATION'=>'Localização Arquivo',
'LBL_PD'=>'Plataforma Dependente',
'LBL_PIND'=>'Plataforma Independente',
'ChoosePlatform'=>'Escolha Plataforma',
'LBL_ACTIVE'=>'Ativo',
'LBL_INACTIVE'=>'Inativo',
'LBL_UPLOAD_BUTTON'=>'Transferir',
'architecture'=>'Arquitetura',
'LBL_DOWNLOAD_FILE'=>'Download Arquivo',
'LBL_CHECK_INTEGRITY'=>'Checar integridade arquivo',
'LBL_EMAIL_FILE'=>'Enviar Email com arquivo anexado',
'LBL_CLICK_HERE'=>'Clique aqui',
'LBL_TO_ADD_FOLDER'=>'para adicionar uma nova pasta.',
'LBL_DELETE_FOLDER'=>'Apagar Pasta',
'LBL_FOLDER_DESC'=>'Descrição',
'LBL_ADD_NEW_FOLDER'=>'Adicionar Pasta',
'LBL_DELETE_DOCUMENTS'=>'Apagar Documento(s)',
'LBL_MOVE_TO'=>'Mover para',
'File Name'=>'Nome Arquivo',
'File Type'=>'Tipo Arquivo',
'File Size'=>'Tamanho',
'LBL_INTERNAL'=>'Interno',
'LBL_URL'=>'URL',
'LBL_EXTERNAL'=>'Externo',
'LBL_EXTERNAL_LNK'=>'Link Externo',
'LBL_ACTIVE'=>'Ativo',
'LBL_INACTIVE'=>'Inativo',
'LBL_PLATFORM_INDEPENDENT'=>'Plataforma Independente',
'LNK_DOWNLOAD'=>'download',
'LBL_MOVE_DOCUMENTS'=>'Mover Documento(s)',
'LBL_MOVE'=>'Mover',
'Download Type'=>'Tipo Download',
'Version'=>'Versão',
'Active'=>'Ativo',
'Download Count'=>'Contar Download',
'Platform'=>'Plataforma',
'Assigned To'=>'Atribuído à',
// Module Sequence Numbering
'Note No' => 'No. Documento',
// END

// Documents module
'LBL_EMPTY_FOLDERS' => 'Pastas Vazias',
'LBL_VIEW_EMPTY_FOLDERS' => 'Visualizar Pastas Vazias',
'LBL_NO_DOCUMENTS' => 'Nenhum Documento',
'LBL_DESCRIPTION' => 'Descrição',
'FILE_HAS_NO_DATA'=>'O arquivo selecionado não possui dados ou o é inválido',

'LBL_MAXIMUM_20'=>'Máximo 20',
'LBL_MAXIMUM_50'=>'Máximo 50',

// Added after 5.1.0 GA
'Folder Name'=>'Nome Pasta',
'Document No'=>'No. Documento',

'Documents' => 'Documentos',
'Documents ID' => 'ID Documentos',
);

?>
